==> apache-iceberg-1.5.1.tar.gz: apache-iceberg-1.5.1/flink/v1.17/flink/src/test/java/org/apache/iceberg/flink/sink/TestAvroGenericRecordToRowDataMapper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iceberg.flink.sink;

import org.apache.flink.table.data.RowData;
import org.apache.iceberg.flink.AvroGenericRecordConverterBase;
import org.apache.iceberg.flink.DataGenerator;
import org.junit.Assert;

public class TestAvroGenericRecordToRowDataMapper extends AvroGenericRecordConverterBase {
  @Override
  protected void testConverter(DataGenerator dataGenerator) throws Exception {
    // Need to use avroSchema from DataGenerator because some primitive types have special Avro
    // type handling. Hence the Avro schema converted from Iceberg schema won't work.
    AvroGenericRecordToRowDataMapper mapper =
        AvroGenericRecordToRowDataMapper.forAvroSchema(dataGenerator.avroSchema());
    RowData expected = dataGenerator.generateFlinkRowData();
    RowData actual = mapper.map(dataGenerator.generateAvroGenericRecord());
    Assert.assertEquals(expected, actual);
  }
}

==> apache-iceberg-1.10.1.tar.gz: apache-iceberg-1.10.1/flink/v1.19/flink/src/test/java/org/apache/iceberg/flink/sink/TestAvroGenericRecordToRowDataMapper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iceberg.flink.sink;

import static org.assertj.core.api.Assertions.assertThat;

import org.apache.flink.table.data.RowData;
import org.apache.iceberg.flink.AvroGenericRecordConverterBase;
import org.apache.iceberg.flink.DataGenerator;

public class TestAvroGenericRecordToRowDataMapper extends AvroGenericRecordConverterBase {
  @Override
  protected void testConverter(DataGenerator dataGenerator) throws Exception {
    // Need to use avroSchema from DataGenerator because some primitive types have special Avro
    // type handling. Hence the Avro schema converted from Iceberg schema won't work.
    AvroGenericRecordToRowDataMapper mapper =
        AvroGenericRecordToRowDataMapper.forAvroSchema(dataGenerator.avroSchema());
    RowData expected = dataGenerator.generateFlinkRowData();
    RowData actual = mapper.map(dataGenerator.generateAvroGenericRecord());
    assertThat(actual).isEqualTo(expected);
  }
}
